pub struct EguiState { /* private fields */ }Expand description
smithay-egui state object
Implementations
Sourceimpl EguiState
impl EguiState
Sourcepub fn context(&self) -> &Context
pub fn context(&self) -> &Context
Retrieve the underlying egui::Context
Sourcepub fn wants_keyboard(&self) -> bool
pub fn wants_keyboard(&self) -> bool
If true, egui is currently listening on text input (e.g. typing text in a TextEdit).
Sourcepub fn wants_pointer(&self) -> bool
pub fn wants_pointer(&self) -> bool
True if egui is currently interested in the pointer (mouse or touch). Could be the pointer is hovering over a Window or the user is dragging a widget. If false, the pointer is outside of any egui area and so you may want to forward it to other clients as usual. Returns false if a drag started outside of egui and then moved over an egui area.
Sourcepub fn handle_device_added(&self, device: &impl Device)
pub fn handle_device_added(&self, device: &impl Device)
Pass new input devices to EguiState for internal tracking
Sourcepub fn handle_device_removed(&self, device: &impl Device)
pub fn handle_device_removed(&self, device: &impl Device)
Remove input devices to EguiState for internal tracking
Sourcepub fn handle_keyboard(
&self,
handle: &KeysymHandle<'_>,
pressed: bool,
modifiers: ModifiersState,
)
pub fn handle_keyboard( &self, handle: &KeysymHandle<'_>, pressed: bool, modifiers: ModifiersState, )
Pass keyboard events into EguiState.
You do not want to pass in events, egui should not react to, but you need to make sure they add up. So for every pressed event, you want to send a released one.
You likely want to use the filter-closure of [smithay::wayland::seat::KeyboardHandle::input] to optain these values.
Use [smithay::wayland::seat::KeysymHandle] and the provided [smithay::wayland::seat::ModifiersState].
Sourcepub fn handle_pointer_motion(&self, position: Point<i32, Logical>)
pub fn handle_pointer_motion(&self, position: Point<i32, Logical>)
Pass new pointer coordinates to EguiState
Pass pointer button presses to EguiState
Note: If you are unsure about which PointerButtonEvents to send to smithay-egui
instead of normal clients, check EguiState::wants_pointer to figure out,
if there is an egui-element below your pointer.
Sourcepub fn handle_pointer_axis(&self, x_amount: f64, y_amount: f64)
pub fn handle_pointer_axis(&self, x_amount: f64, y_amount: f64)
Pass a pointer axis scrolling to EguiState
Note: If you are unsure about which PointerAxisEvents to send to smithay-egui
instead of normal clients, check EguiState::wants_pointer to figure out,
if there is an egui-element below your pointer.
Sourcepub fn set_focused(&self, focused: bool)
pub fn set_focused(&self, focused: bool)
Set if this EguiState should consider itself focused
Sourcepub fn render(
&self,
ui: impl FnMut(&Context),
renderer: &mut GlowRenderer,
area: Rectangle<i32, Logical>,
scale: f64,
alpha: f32,
) -> Result<TextureRenderElement<GlesTexture>, GlesError>
pub fn render( &self, ui: impl FnMut(&Context), renderer: &mut GlowRenderer, area: Rectangle<i32, Logical>, scale: f64, alpha: f32, ) -> Result<TextureRenderElement<GlesTexture>, GlesError>
Produce a new frame of egui. Returns a [RenderElement]
uiis your drawing functionrendereris aGlowRendererarealimits the space egui will be using and offsets the resultscaleis the scale egui should render inalphaapplies (additional) transparency to the whole uistart_timeneed to be a fixed point in time before the firstruncall to measure animation-times and the like.modifiersshould be the current state of modifiers pressed on the keyboards.
Sourcepub fn set_zindex(&self, idx: u8)
pub fn set_zindex(&self, idx: u8)
Sets the z_index as reported by SpaceElement::z_index.
The default is RenderZindex::Overlay.
Sourcepub fn last_output(&self) -> Option<PlatformOutput>
pub fn last_output(&self) -> Option<PlatformOutput>
Returns the egui PlatformOutput generated by the last Self::render call